Docbook : a simple Markdown CMS
===============================

**DocBook** is a simple PHP tool to build rich HTML views from Markdown files following a 
filesystem architecture. It embedded some classic website features like a search in contents,
some RSS feeds generation or translations switching.

**DocBook** builds a "like-a-book" interactive website from simple Markdown files.


## Features

DocBook is a simple application organized beyond a filesystem architecture of Markdown files.
Each file is a "page" and each sub-directory is a "section" of pages. The title of the files 
or directories is used to be the title of the page or section.

For each file, a set of dependances can be defined to overwrite the default value, that must 
itself be defined at the project root directory. These files are, by default:

-   `*.copyright.md`: a copyright, license or protection information for the file content,
-   `*.author(s).md`: an information about the author(s) of the file,
-   `*.changelog.md`: the evolutions informations of the file.


### Markdown syntax

The Markdown syntax used by DocBook follows the [Extended Markdown](https://github.com/atelierspierrot/extended-markdown)
rules. They are inherited from:

-   the original [John Gruber's syntax](http://daringfireball.net/projects/markdown/syntax),
-   the ["extra" version from Michel Fortin](http://michelf.ca/projects/php-markdown/concepts/),
-   some features are also included from the [Fletcher Penny's MultiMarkdown](http://fletcher.github.com/peg-multimarkdown/).


### Translations

Each document can be translated, naming the translation file like:

    CONTENT.md
    CONTENT.fr.md // translation in French
    ...


### URL routing

Globally or for each of your DocBook directories, the following routes are available:

-   `*/sitemap`: build a sitemap XML from this position and through its children,
-   `*/notes`: build a page referencing all footnotes from this position and through its children,
-   `*/glossary`: build a page referencing all glossary entries from this position and through 
    its children,
-   `*/bibliography`: build a page referencing all bibliographic entries from this position and 
    through its children,
-   `*/rss`: build an RSS feed of contents from this position and through its children,
-   `*/search?s=A&ln=LN`: process a search of string "A" in contents from this position and through 
    its children in the specified language if defined.

For each file of your DocBook, the following URLs are available:

-   `*/ln?LN`: get this content in LN language if present,
-   `*/plain`: get the plain text version of the page.


## Organization


### Special files

Any file named `INDEX.md` in a directory will be considered as its index and be delivered if 
no other file is requested in the URL.

Any file named `README.md` in a directory will be displayed at tht bottom of the default Apache 
indexing of the directory content.


### Architecture

The default global architecture of your DocBook is:

    | bin/
    | src/
    | tmp/
    | user/
    | www/

-   `bin/` contains the Apache shell script which will handle all requests and the application 
    installer/updater ;

-   `src/` contains the PHP sources of the application and the template files ; to define a 
    new template, put your file here ; it must follow an architecture like:

        | src/
        | ---- config/
        | ---- DocBook/
        | ---- templates/

-   `tmp/` is a sub-directory to store some configurations and some cached files ; the best 
    practice is to not touch them but you can, in extreme conditions, erase all their 
    contents without worry ; it is (re-)generated by the application ;

-   `user/` is the directory to put your own user configuration or templates (*see the 
    [Fallback system](#fallback-system) section for more infos*) ; you can create it as it
    doesn't exist in the distribution ; it may follow an architecture like:

        | user/
        | ---- config/
        | ---- templates/

-   `www/` sub-directory must be the `DOCUMENT_ROOT` of your virtual host (*anything outside 
    this directory is not used in HTML pages*) ; it must follow an architecture like:

        | www/
        | ---- assets/
        | ---- .htaccess
        | ---- docbook.php

**NOTE** - A `vendor/` sub-directory will be created by the application in both `src/` and 
`www/` directories to store the vendor external packages used by DocBook ; do not modify them.
    

### Data files organization

All your Markdown files, the real pages of your website, have to be stored in the `www/` 
directory.

By default, any file contained in a directory named `wip/` will not be displayed publicly 
and will not be referenced in the sitemap neither in the index ; to view it, you will have 
to manually write its URL (*see the [Routing](#url-routing) section of this document to 
learn more about the application URLs'construction*). 


### Configuration settings

The list below shows the configuration entries available:

| Variable               | Value type                                                |
| ---------------------- | --------------------------------------------------------- |
| EMD\_CHARSET           | A valid [Content-type][contentype] info                   | 
| EMD\_CONSOLE\_OPTIONS  | A set of options passed to the console                    | 
| EMD\_TPL               | The default template file used to generate pages views    | 


[contentype]: http://www.faqs.org/rfcs/rfc2616.html


### Fallback system

The application is constructed to allow user to overwrite some configuration settings and
the templates used for pages building. This feature is quite simple:

-   by default, some configurations and templates are embedded with the application in 
    the `src/config/` and `src/templates/` directories ;
-   any file found in the `user/config/` will be taken primary to the default config and
    any file found in the `user/templates/` will be taken primary to the default templates.

Templates follows a specific rule as the application can use a collection of templates to
build different designs for pages.
    


----
**Copyleft (c) 2008-2013 [Les Ateliers Pierrot](http://www.ateliers-pierrot.fr/)** - Paris, France - Some rights reserved.

Scripts are licensed under the [GNU General Public License version 3](http://www.gnu.org/licenses/gpl.html).

Contents are licensed under the [Creative Commons - Attribution - Share Alike - Unported - version 3.0](http://creativecommons.org/licenses/by-sa/3.0/) license.
